==> ejc-techmanagement-impl-3.0.0-20250423.013417-103-sources.jar: com/ejianc/business/techmanagement/controller/ConstructionSchemeController.java <==
package com.ejianc.business.techmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.techmanagement.bean.ConstructionDisclosureEntity;
import com.ejianc.business.techmanagement.service.IConstructionDisclosureService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.techmanagement.bean.ConstructionSchemeEntity;
import com.ejianc.business.techmanagement.service.IConstructionSchemeService;
import com.ejianc.business.techmanagement.vo.ConstructionSchemeVO;

/**
 * 施工方案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("constructionScheme")
public class ConstructionSchemeController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    private static final String BILL_CODE = "CONSTRUCTION-SCHEME";//此处需要根据实际修改

    @Autowired
    private IConstructionSchemeService service;
    @Autowired
    private IConstructionDisclosureService disclosureService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ConstructionSchemeVO> saveOrUpdate(@RequestBody ConstructionSchemeVO saveOrUpdateVO) {
    	ConstructionSchemeEntity entity = BeanMapper.map(saveOrUpdateVO, ConstructionSchemeEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	ConstructionSchemeVO vo = BeanMapper.map(entity, ConstructionSchemeVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ConstructionSchemeVO> queryDetail(Long id) {
    	ConstructionSchemeEntity entity = service.selectById(id);
    	ConstructionSchemeVO vo = BeanMapper.map(entity, ConstructionSchemeVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ConstructionSchemeVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ConstructionSchemeVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ConstructionSchemeVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ConstructionSchemeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("buildUnitName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("departmentName");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));


        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));


        IPage<ConstructionSchemeEntity> page = service.queryPage(param,false);
        IPage<ConstructionSchemeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<ConstructionSchemeVO> constructionSchemeList = BeanMapper.mapList(page.getRecords(), ConstructionSchemeVO.class);
        for (ConstructionSchemeVO constructionSchemeVO : constructionSchemeList) {
            constructionSchemeVO.setDisclosureStateName(0 == constructionSchemeVO.getDisclosureState() ? "未交底" : "已交底");
        }
        pageData.setRecords(constructionSchemeList);

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("buildUnitName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("departmentName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ConstructionSchemeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<ConstructionSchemeVO> voList = BeanMapper.mapList(list, ConstructionSchemeVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
            e.setDisclosureStateName(0 == e.getDisclosureState() ? "未交底" : "已交底");
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("ConstructionScheme-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refConstructionSchemeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ConstructionSchemeVO>> refConstructionSchemeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");

        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("billState", new Parameter(QueryParam.IN, Arrays.asList(1, 3)));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            if (_con.containsKey("projectId")){
                Long projectId = _con.getLongValue("projectId");
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, projectId));
                List<ConstructionDisclosureEntity> disclosureList = disclosureService.queryDisclosureByProjectId(projectId);
                if (CollectionUtils.isNotEmpty(disclosureList)){
                    List<Long> schemeIdList = disclosureList.stream().map(ConstructionDisclosureEntity::getSchemeId).collect(Collectors.toList());
                    param.getParams().put("id", new Parameter(QueryParam.NOT_IN, schemeIdList));
                }
            }
        }

        IPage<ConstructionSchemeEntity> page = service.queryPage(param,false);
        IPage<ConstructionSchemeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ConstructionSchemeVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-techmanagement-impl-3.0.0-20250807.060007-110-sources.jar: com/ejianc/business/techmanagement/controller/ConstructionSchemeController.java <==
package com.ejianc.business.techmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.techmanagement.bean.ConstructionDisclosureEntity;
import com.ejianc.business.techmanagement.service.IConstructionDisclosureService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.techmanagement.bean.ConstructionSchemeEntity;
import com.ejianc.business.techmanagement.service.IConstructionSchemeService;
import com.ejianc.business.techmanagement.vo.ConstructionSchemeVO;

/**
 * 施工方案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("constructionScheme")
public class ConstructionSchemeController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    private static final String BILL_CODE = "CONSTRUCTION-SCHEME";//此处需要根据实际修改

    @Autowired
    private IConstructionSchemeService service;
    @Autowired
    private IConstructionDisclosureService disclosureService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ConstructionSchemeVO> saveOrUpdate(@RequestBody ConstructionSchemeVO saveOrUpdateVO) {
    	ConstructionSchemeEntity entity = BeanMapper.map(saveOrUpdateVO, ConstructionSchemeEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	ConstructionSchemeVO vo = BeanMapper.map(entity, ConstructionSchemeVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ConstructionSchemeVO> queryDetail(Long id) {
    	ConstructionSchemeEntity entity = service.selectById(id);
    	ConstructionSchemeVO vo = BeanMapper.map(entity, ConstructionSchemeVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ConstructionSchemeVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ConstructionSchemeVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ConstructionSchemeVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ConstructionSchemeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("buildUnitName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("departmentName");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));


        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));


        IPage<ConstructionSchemeEntity> page = service.queryPage(param,false);
        IPage<ConstructionSchemeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<ConstructionSchemeVO> constructionSchemeList = BeanMapper.mapList(page.getRecords(), ConstructionSchemeVO.class);
        for (ConstructionSchemeVO constructionSchemeVO : constructionSchemeList) {
            constructionSchemeVO.setDisclosureStateName(0 == constructionSchemeVO.getDisclosureState() ? "未交底" : "已交底");
        }
        pageData.setRecords(constructionSchemeList);

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("buildUnitName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("departmentName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ConstructionSchemeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<ConstructionSchemeVO> voList = BeanMapper.mapList(list, ConstructionSchemeVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
            e.setDisclosureStateName(0 == e.getDisclosureState() ? "未交底" : "已交底");
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("ConstructionScheme-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refConstructionSchemeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ConstructionSchemeVO>> refConstructionSchemeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("schemeName");
        fuzzyFields.add("schemeCodePlan");
        fuzzyFields.add("schemeCode");

        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("billState", new Parameter(QueryParam.IN, Arrays.asList(1, 3)));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            if (_con.containsKey("projectId")){
                Long projectId = (Long) _con.getLongValue("projectId");
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, projectId));
                List<ConstructionDisclosureEntity> disclosureList = disclosureService.queryDisclosureByProjectId(projectId);
                if (CollectionUtils.isNotEmpty(disclosureList)){
                    List<Long> schemeIdList = disclosureList.stream().map(ConstructionDisclosureEntity::getSchemeId).collect(Collectors.toList());
                    param.getParams().put("id", new Parameter(QueryParam.NOT_IN, schemeIdList));
                }
            }
        }

        IPage<ConstructionSchemeEntity> page = service.queryPage(param,false);
        IPage<ConstructionSchemeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ConstructionSchemeVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
